@@ -753,14 +753,11 @@ class ProfileStats:
                 )
             # Same as before, this I've sacrificed some information making
             # the output more readable
+        percent = sum(f for f, t, a, nd_id, nb_call in atimes[N:])
+        duration = sum(t for f, t, a, nd_id, nb_call in atimes[N:])
         print(
-            "   ... (remaining %i Apply instances account for "
-            "%.2f%%(%.2fs) of the runtime)"
-            % (
-                max(0, len(atimes) - N),
-                sum(f for f, t, a, nd_id, nb_call in atimes[N:]),
-                sum(t for f, t, a, nd_id, nb_call in atimes[N:]),
-            ),
+            f"   ... (remaining {max(0, len(atimes) - N)} Apply instances account for "
+            f"{percent:.2f}%%({duration:.2f}s) of the runtime)",
             file=file,
         )
         print("", file=file)
@@ -1380,9 +1377,9 @@ class ProfileStats:
         items.sort(key=lambda a: a[1], reverse=True)
         for idx, ((fgraph, node), node_outputs_size) in enumerate(items[:N]):
             code = ["c"] * len(node.outputs)
-            for out, inp in node.op.destroy_map.items():
+            for out in node.op.destroy_map:
                 code[out] = "i"
-            for out, inp in node.op.view_map.items():
+            for out in node.op.view_map:
                 code[out] = "v"
             shapes = str(fct_shapes[fgraph][node])
 
@@ -1569,26 +1566,26 @@ class ProfileStats:
             printed_tip = True
 
         # tip 2
-        if not config.lib__amblibm and any(
+        if not config.lib__amdlibm and any(
             amdlibm_speed_up(a.op) for (fgraph, a) in self.apply_time
         ):
             print(
                 "  - Try installing amdlibm and set the PyTensor flag "
-                "lib__amblibm=True. This speeds up only some Elemwise "
+                "lib__amdlibm=True. This speeds up only some Elemwise "
                 "operation.",
                 file=file,
             )
             printed_tip = True
 
         # tip 3
-        if not config.lib__amblibm and any(
+        if not config.lib__amdlibm and any(
             exp_float32_op(a.op) and a.inputs[0].dtype == "float32"
             for (fgraph, a) in self.apply_time
         ):
             print(
                 "  - With the default gcc libm, exp in float32 is slower "
                 "than in float64! Try PyTensor flag floatX=float64, or "
-                "install amdlibm and set the pytensor flags lib__amblibm=True",
+                "install amdlibm and set the pytensor flags lib__amdlibm=True",
                 file=file,
             )
             printed_tip = True
