@@ -1806,19 +1806,12 @@ class BatchedDot(COp):
             strides = f"PyArray_STRIDES({var})"
             if ndim == 1:
                 return f"{strides}[0] == type_size"
-            return " && ".join(
-                [
-                    " && ".join(
-                        f"{strides}[{i}] > 0 && {strides}[{i}] % type_size == 0"
-                        for i in range(1, ndim)
-                    ),
-                    "({})".format(
-                        " || ".join(
-                            f"{strides}[{i}] == type_size" for i in range(1, ndim)
-                        )
-                    ),
-                ]
+            ands = " && ".join(
+                f"{strides}[{i}] > 0 && {strides}[{i}] % type_size == 0"
+                for i in range(1, ndim)
             )
+            ors = " || ".join(f"{strides}[{i}] == type_size" for i in range(1, ndim))
+            return f"{ands} && ({ors})"
 
         x_ndim, y_ndim, z_ndim = (
             node.inputs[0].ndim,
@@ -1834,11 +1827,11 @@ class BatchedDot(COp):
         ]
 
         z_shape_correct = " && ".join(
-            "PyArray_DIMS(%s)[%i] == %s" % (_z, i, dim) for i, dim in enumerate(z_dims)
+            f"PyArray_DIMS({_z})[{i}] == {dim}" for i, dim in enumerate(z_dims)
         )
         z_shape = ", ".join(z_dims)
         z_contiguous = contiguous(_z, z_ndim)
-        allocate = """
+        allocate = f"""
             if (NULL == {_z} || !({z_shape_correct})  || !({z_contiguous}))
             {{
                 npy_intp dims[{z_ndim}] = {{{z_shape}}};
@@ -1851,14 +1844,14 @@ class BatchedDot(COp):
                     {fail}
                 }}
             }}
-        """.format(**locals())
+        """
 
         # code to reallocate inputs contiguously if necessary
         contiguate = []
         for var, ndim in [(_x, x_ndim), (_y, y_ndim)]:
             _contiguous = contiguous(var, ndim)
             contiguate.append(
-                """
+                f"""
                 if (!({_contiguous})) {{
                     PyArrayObject * _copy = (PyArrayObject *) PyArray_Copy({var});
                     if (!_copy)
@@ -1866,11 +1859,11 @@ class BatchedDot(COp):
                     Py_XDECREF({var});
                     {var} = _copy;
                 }}
-            """.format(**locals())
+            """
             )
         contiguate = "\n".join(contiguate)
 
-        return """
+        return f"""
         int type_num = PyArray_DESCR({_x})->type_num;
         int type_size = PyArray_DESCR({_x})->elsize; // in bytes
 
@@ -1927,7 +1920,7 @@ class BatchedDot(COp):
             }}
             break;
         }}
-        """.format(**locals())
+        """
 
     def c_code_cache_version(self):
         from pytensor.tensor.blas_headers import blas_header_version
