@@ -1,6 +1,6 @@
 import itertools
 import sys
-from collections import defaultdict, deque
+from collections import Counter, defaultdict, deque
 from collections.abc import Generator
 from functools import cache
 from typing import TypeVar
@@ -14,7 +14,7 @@ from pytensor.configdefaults import config
 from pytensor.graph import FunctionGraph
 from pytensor.graph.basic import Apply, Constant, Variable, ancestors, io_toposort
 from pytensor.graph.features import ReplaceValidate
-from pytensor.graph.fg import ApplyOrOutput
+from pytensor.graph.fg import Output
 from pytensor.graph.rewriting.basic import (
     EquilibriumGraphRewriter,
     GraphRewriter,
@@ -71,7 +71,7 @@ class InplaceElemwiseOptimizer(GraphRewriter):
         ndim = prof["ndim"]
         if ndim:
             print(blanc, "ndim", "nb", file=stream)
-            for n in sorted(ndim.keys()):
+            for n in sorted(ndim):
                 print(blanc, n, ndim[n], file=stream)
 
     def candidate_input_idxs(self, node):
@@ -127,7 +127,7 @@ class InplaceElemwiseOptimizer(GraphRewriter):
             "nb_call_replace": 0,
             "nb_call_validate": 0,
             "nb_inconsistent": 0,
-            "ndim": defaultdict(int),
+            "ndim": Counter(),
         }
 
         check_each_change = config.tensor__insert_inplace_optimizer_validate_nb
@@ -688,7 +688,7 @@ class FusionOptimizer(GraphRewriter):
             """
 
             FUSEABLE_MAPPING = defaultdict[Variable, list[Apply]]
-            UNFUSEABLE_MAPPING = defaultdict[Variable, set[ApplyOrOutput]]
+            UNFUSEABLE_MAPPING = defaultdict[Variable, set[Apply]]
 
             def initialize_fuseable_mappings(
                 *, fg: FunctionGraph
@@ -727,7 +727,6 @@ class FusionOptimizer(GraphRewriter):
                     for client, _ in clients:
                         if (
                             out_maybe_fuseable
-                            and not isinstance(client, str)  # "output"
                             and isinstance(client.op, Elemwise)
                             # and not isinstance(client.op.scalar_op, ps.Composite)
                             and len(client.outputs) == 1
@@ -841,7 +840,7 @@ class FusionOptimizer(GraphRewriter):
                             implied_unfuseable_clients = {
                                 c
                                 for client in unfuseable_clients_clone.get(next_out, ())
-                                if not isinstance(client, str)  # "output"
+                                if not isinstance(client.op, Output)
                                 for c in client.outputs
                             }
 
